@@ -1,7 +1,7 @@
 ###############################################################################
 # R (https://r-project.org/) Numeric Methods for Optimization of Portfolios
 #
-# Copyright (c) 2004-2018 Brian G. Peterson, Peter Carl, Ross Bennett, Kris Boudt
+# Copyright (c) 2004-2021 Brian G. Peterson, Peter Carl, Ross Bennett, Kris Boudt
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
@@ -10,7 +10,7 @@
 #
 ###############################################################################
 
-chart.Weights.RP <- function(object, ..., neighbors = NULL, main="Weights", las = 3, xlab=NULL, cex.lab = 1, element.color = "darkgray", cex.axis=0.8, colorset=NULL, legend.loc="topright", cex.legend=0.8, plot.type="line"){
+chart.Weight.RP <- function(object, ..., neighbors = NULL, main="Weights", las = 3, xlab=NULL, cex.lab = 1, element.color = "darkgray", cex.axis=0.8, colorset=NULL, legend.loc="topright", cex.legend=0.8, plot.type="line"){
   # Specific to the output of the random portfolio code with constraints
   if(!inherits(object, "optimize.portfolio.random")){
     stop("object must be of class 'optimize.portfolio.random'")
@@ -90,8 +90,8 @@ chart.Weights.RP <- function(object, ..., neighbors = NULL, main="Weights", las
 
 #' @rdname chart.Weights
 #' @method chart.Weights optimize.portfolio.random
-#' @S3method chart.Weights optimize.portfolio.random
-chart.Weights.optimize.portfolio.random <- chart.Weights.RP
+#' @export
+chart.Weights.optimize.portfolio.random <- chart.Weight.RP
 
 chart.Scatter.RP <- function(object, ..., neighbors = NULL, return.col='mean', risk.col='ES', chart.assets=FALSE, element.color = "darkgray", cex.axis=0.8, xlim=NULL, ylim=NULL){
   # more or less specific to the output of the random portfolio code with constraints
@@ -258,7 +258,7 @@ chart.Scatter.RP <- function(object, ..., neighbors = NULL, return.col='mean', r
 
 #' @rdname chart.RiskReward
 #' @method chart.RiskReward optimize.portfolio.random
-#' @S3method chart.RiskReward optimize.portfolio.random
+#' @export
 chart.RiskReward.optimize.portfolio.random <- chart.Scatter.RP
 
 
@@ -270,14 +270,14 @@ charts.RP <- function(RP, risk.col, return.col, chart.assets=FALSE, neighbors=NU
   par(mar=c(4,4,4,2))
   chart.Scatter.RP(object=RP, risk.col=risk.col, return.col=return.col, chart.assets=chart.assets, neighbors=neighbors, main=main, xlim=NULL, ylim=NULL, ...)
   par(mar=c(2,4,0,2))
-  chart.Weights.RP(object=RP, main="", neighbors=neighbors, ...)
+  chart.Weight.RP(object=RP, main="", neighbors=neighbors, ...)
   par(op)
 }
 
 
 #' @rdname plot
 #' @method plot optimize.portfolio.random
-#' @S3method plot optimize.portfolio.random
+#' @export
 plot.optimize.portfolio.random <- function(x, ..., return.col='mean', risk.col='ES',  chart.assets=FALSE, neighbors=NULL, xlim=NULL, ylim=NULL, main='optimized portfolio plot') {
     charts.RP(RP=x, risk.col=risk.col, return.col=return.col, chart.assets=chart.assets, neighbors=neighbors, main=main, xlim=xlim, ylim=ylim, ...)
 }
@@ -285,7 +285,7 @@ plot.optimize.portfolio.random <- function(x, ..., return.col='mean', risk.col='
 
 #' @rdname plot
 #' @method plot optimize.portfolio
-#' @S3method plot optimize.portfolio
+#' @export
 plot.optimize.portfolio <- function(x, ...,  return.col='mean', risk.col='ES',  chart.assets=FALSE, neighbors=NULL, xlim=NULL, ylim=NULL, main='optimized portfolio plot') {
     charts.RP(RP=x, risk.col=risk.col, return.col=return.col, chart.assets=chart.assets, neighbors=neighbors, main=main, xlim=xlim, ylim=ylim, ...)
 }
\ No newline at end of file
