@@ -281,7 +281,7 @@ set.portfolio.moments <- set.portfolio.moments_v2 <- function(R,
              }, # end switch on var, sd, StdDev
              mVaR =,
              VaR = ,
-             EQS = {
+             CSM = {
                switch(method,
                       sample = {
                         if(is.null(momentargs$mu)) momentargs$mu = matrix( as.vector(apply(tmpR, 2, 'mean')), ncol=1);
@@ -416,7 +416,7 @@ portfolio.moments.boudt <- function(R, portfolio, momentargs=NULL, k=1, ...){
              },
              mVaR =,
              VaR = ,
-             EQS = {
+             CSM = {
                if(is.null(momentargs$mu)) momentargs$mu = matrix( as.vector(apply(R,2,'mean')),ncol=1)
                if(is.null(momentargs$sigma)) momentargs$sigma = extractCovariance(fit)
                if(is.null(momentargs$m3)) momentargs$m3 = extractCoskewness(fit)
@@ -502,7 +502,7 @@ portfolio.moments.bl <- function(R, portfolio, momentargs=NULL, P, Mu=NULL, Sigm
              },
              mVaR =,
              VaR = ,
-             EQS = {
+             CSM = {
                if(is.null(momentargs$mu)) momentargs$mu = B$BLMu
                if(is.null(momentargs$sigma)) momentargs$sigma = B$BLSigma
                if(is.null(momentargs$m3)) momentargs$m3 = PerformanceAnalytics::M3.MM(R)
